@@ -612,7 +612,7 @@ class TestHandleHost(testtools.TestCase):
         mock_make_event.return_value = test_event
 
         status_tag = ElementTree.fromstring(STATUS_TAG_XML)
-        node_state_tag_list = status_tag.getchildren()
+        node_state_tag_list = list(status_tag)
 
         obj = handle_host.HandleHost()
         obj._check_if_status_changed(node_state_tag_list)
@@ -642,19 +642,15 @@ class TestHandleHost(testtools.TestCase):
     @mock.patch.object(handle_host.HandleHost, '_check_if_status_changed')
     @mock.patch.object(parse_crmmon_xml.ParseCrmMonXml,
                        'get_node_state_tag_list')
-    @mock.patch.object(parse_crmmon_xml.ParseCrmMonXml,
-                       'has_quorum')
     @mock.patch.object(parse_crmmon_xml.ParseCrmMonXml, 'set_crmmon_xml')
     @mock.patch.object(handle_host.HandleHost, '_get_crmmon_xml')
     def test_check_host_status_by_crm_mon(
         self, mock_get_crmmon_xml, mock_set_crmmon_xml,
-        mock_has_quorum, mock_get_node_state_tag_list,
-        mock_check_if_status_changed):
+        mock_get_node_state_tag_list, mock_check_if_status_changed):
         mock_get_crmmon_xml.return_value = CRMMON_NODES_TAG_XML
         mock_set_crmmon_xml.return_value = None
-        mock_has_quorum.return_value = True
         status_tag = ElementTree.fromstring(CRMMON_NODES_TAG_XML)
-        node_state_tag_list = status_tag.getchildren()
+        node_state_tag_list = list(status_tag)
         mock_get_node_state_tag_list.return_value = node_state_tag_list
         mock_check_if_status_changed.return_value = None
 
@@ -662,6 +658,7 @@ class TestHandleHost(testtools.TestCase):
         ret = obj._check_host_status_by_crm_mon()
 
         self.assertEqual(0, ret)
+        mock_get_node_state_tag_list.assert_called_once_with()
         mock_set_crmmon_xml.assert_called_once_with(CRMMON_NODES_TAG_XML)
         mock_get_node_state_tag_list.assert_called_once_with()
         mock_check_if_status_changed.assert_called_once_with(
@@ -670,42 +667,20 @@ class TestHandleHost(testtools.TestCase):
                 {'uname': 'remote2', 'crmd': 'online'},
                 {'uname': 'remote3', 'crmd': 'online'}])
 
-    @mock.patch.object(handle_host.HandleHost, '_check_if_status_changed')
-    @mock.patch.object(parse_crmmon_xml.ParseCrmMonXml,
-                       'has_quorum')
-    @mock.patch.object(parse_crmmon_xml.ParseCrmMonXml, 'set_crmmon_xml')
-    @mock.patch.object(handle_host.HandleHost, '_get_crmmon_xml')
-    def test_check_host_status_by_crm_mon_no_quorum(
-        self, mock_get_crmmon_xml, mock_set_crmmon_xml,
-        mock_has_quorum, mock_check_if_status_changed):
-        mock_get_crmmon_xml.return_value = CRMMON_NODES_TAG_XML
-        mock_set_crmmon_xml.return_value = None
-        mock_has_quorum.return_value = False
-
-        obj = handle_host.HandleHost()
-        ret = obj._check_host_status_by_crm_mon()
-
-        self.assertEqual(2, ret)
-        mock_set_crmmon_xml.assert_called_once_with(CRMMON_NODES_TAG_XML)
-        mock_check_if_status_changed.assert_not_called()
-
-    @mock.patch.object(parse_crmmon_xml.ParseCrmMonXml,
-                       'has_quorum')
     @mock.patch.object(parse_crmmon_xml.ParseCrmMonXml,
                        'get_node_state_tag_list')
     @mock.patch.object(parse_crmmon_xml.ParseCrmMonXml, 'set_crmmon_xml')
     @mock.patch.object(handle_host.HandleHost, '_get_crmmon_xml')
     def test_check_host_status_by_crm_mon_not_have_node_state_tag(
         self, mock_get_crmmon_xml, mock_set_crmmon_xml,
-        mock_get_node_state_tag_list, mock_has_quorum):
+        mock_get_node_state_tag_list):
         mock_get_crmmon_xml.return_value = CRMMON_NODES_TAG_XML
         mock_set_crmmon_xml.return_value = None
         mock_get_node_state_tag_list.return_value = []
-        mock_has_quorum.return_value = True
 
         obj = handle_host.HandleHost()
 
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             Exception, "Failed to get nodes tag from crm_mon xml.",
             obj._check_host_status_by_crm_mon)
         mock_get_crmmon_xml.assert_called_once_with()
@@ -735,7 +710,7 @@ class TestHandleHost(testtools.TestCase):
         mock_set_cib_xml.return_value = None
         mock_have_quorum.return_value = 1
         status_tag = ElementTree.fromstring(STATUS_TAG_XML)
-        node_state_tag_list = status_tag.getchildren()
+        node_state_tag_list = list(status_tag)
         mock_get_node_state_tag_list.return_value = node_state_tag_list
         mock_check_if_status_changed.return_value = None
 
@@ -751,24 +726,31 @@ class TestHandleHost(testtools.TestCase):
             node_state_tag_list)
 
     @mock.patch.object(handle_host.HandleHost, '_check_if_status_changed')
+    @mock.patch.object(parse_cib_xml.ParseCibXml, 'get_node_state_tag_list')
     @mock.patch.object(parse_cib_xml.ParseCibXml, 'have_quorum')
     @mock.patch.object(parse_cib_xml.ParseCibXml, 'set_cib_xml')
     @mock.patch.object(handle_host.HandleHost, '_get_cib_xml')
     def test_check_host_status_by_cibadmin_no_quorum(
         self, mock_get_cib_xml, mock_set_cib_xml, mock_have_quorum,
-        mock_check_if_status_changed):
+        mock_get_node_state_tag_list, mock_check_if_status_changed):
         mock_get_cib_xml.return_value = STATUS_TAG_XML
         mock_set_cib_xml.return_value = None
         mock_have_quorum.return_value = 0
+        status_tag = ElementTree.fromstring(STATUS_TAG_XML)
+        node_state_tag_list = list(status_tag)
+        mock_get_node_state_tag_list.return_value = node_state_tag_list
+        mock_check_if_status_changed.return_value = None
 
         obj = handle_host.HandleHost()
         ret = obj._check_host_status_by_cibadmin()
 
-        self.assertEqual(2, ret)
+        self.assertEqual(0, ret)
         mock_get_cib_xml.assert_called_once_with()
         mock_set_cib_xml.assert_called_once_with(STATUS_TAG_XML)
         mock_have_quorum.assert_called_once_with()
-        mock_check_if_status_changed.assert_not_called()
+        mock_get_node_state_tag_list.assert_called_once_with()
+        mock_check_if_status_changed.assert_called_once_with(
+            node_state_tag_list)
 
     @mock.patch.object(handle_host.HandleHost, '_get_cib_xml')
     def test_check_host_status_by_cibadmin_cib_xml_is_None(
@@ -795,7 +777,7 @@ class TestHandleHost(testtools.TestCase):
 
         obj = handle_host.HandleHost()
 
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             Exception, "Failed to get node_state tag from cib xml.",
             obj._check_host_status_by_cibadmin)
         mock_get_cib_xml.assert_called_once_with()
@@ -820,25 +802,25 @@ class TestHandleHost(testtools.TestCase):
     def test_monitor_hosts(self,
                            mock_check_hb_line,
                            mock_check_pacemaker_services,
-                           mock_check_host_status_by_crmadmin,
                            mock_check_host_status_by_cibadmin,
+                           mock_check_host_status_by_crmadmin,
                            mock_sleep):
 
         mock_check_hb_line.side_effect = \
-            [0, 1, 2, 0, Exception("Test exception."), 0, KeyboardInterrupt()]
-        mock_check_pacemaker_services.side_effect = [True, False, False, True]
+            [0, 1, 2, 0, Exception("Test exception.")]
+        mock_check_pacemaker_services.side_effect = [True, False, False]
+        mock_check_host_status_by_cibadmin.side_effect = [0, 1]
         mock_check_host_status_by_crmadmin.side_effect = [0, 1]
-        mock_check_host_status_by_cibadmin.side_effect = [0, 1, 0]
         mock_sleep.return_value = None
 
         obj = handle_host.HandleHost()
-        self.assertRaises(KeyboardInterrupt, obj.monitor_hosts)
+        obj.monitor_hosts()
 
-        self.assertEqual(7, mock_check_hb_line.call_count)
-        self.assertEqual(4, mock_check_pacemaker_services.call_count)
+        self.assertEqual(5, mock_check_hb_line.call_count)
+        self.assertEqual(3, mock_check_pacemaker_services.call_count)
         mock_check_pacemaker_services.assert_called_with('pacemaker_remote')
+        self.assertEqual(2, mock_check_host_status_by_cibadmin.call_count)
         self.assertEqual(2, mock_check_host_status_by_crmadmin.call_count)
-        self.assertEqual(3, mock_check_host_status_by_cibadmin.call_count)
 
     @mock.patch.object(eventlet.greenthread, 'sleep')
     @mock.patch.object(handle_host.HandleHost,
@@ -853,15 +835,16 @@ class TestHandleHost(testtools.TestCase):
 
         CONF.host.restrict_to_remotes = True
         mock_check_hb_line.side_effect = \
-            [0, Exception("Test exception."), 0, KeyboardInterrupt()]
+            [0, Exception("Test exception.")]
         mock_check_pacemaker_services.return_value = True
-        mock_check_host_status_by_crm_mon.return_value = 0
+        mock_check_host_status_by_crm_mon.side_effect = 0
         mock_sleep.return_value = None
 
         obj = handle_host.HandleHost()
-        self.assertRaises(KeyboardInterrupt, obj.monitor_hosts)
+        obj.monitor_hosts()
 
-        self.assertEqual(4, mock_check_hb_line.call_count)
-        self.assertEqual(2, mock_check_pacemaker_services.call_count)
+        self.assertEqual(1, mock_check_hb_line.call_count)
+        self.assertEqual(1, mock_check_pacemaker_services.call_count)
         mock_check_pacemaker_services.assert_called_with('pacemaker_remote')
-        self.assertEqual(2, mock_check_host_status_by_crm_mon.call_count)
+        self.assertEqual(1, mock_check_host_status_by_crm_mon.call_count)
+        mock_check_host_status_by_crm_mon.assert_called_once_with()
